[Scummvm-cvs-logs] SF.net SVN: scummvm: [26184] scummvm/trunk/engines/parallaction

peres001 at users.sourceforge.net peres001 at users.sourceforge.net
Sat Mar 17 21:51:13 CET 2007


Revision: 26184
          http://scummvm.svn.sourceforge.net/scummvm/?rev=26184&view=rev
Author:   peres001
Date:     2007-03-17 13:51:13 -0700 (Sat, 17 Mar 2007)

Log Message:
-----------
renamed structures to be more general

Modified Paths:
--------------
    scummvm/trunk/engines/parallaction/defs.h
    scummvm/trunk/engines/parallaction/graphics.cpp
    scummvm/trunk/engines/parallaction/parallaction.h
    scummvm/trunk/engines/parallaction/zone.cpp
    scummvm/trunk/engines/parallaction/zone.h

Modified: scummvm/trunk/engines/parallaction/defs.h
===================================================================
--- scummvm/trunk/engines/parallaction/defs.h	2007-03-17 20:48:23 UTC (rev 26183)
+++ scummvm/trunk/engines/parallaction/defs.h	2007-03-17 20:51:13 UTC (rev 26184)
@@ -93,7 +93,7 @@
 
 struct Animation;
 struct Zone;
-struct ZoneLabel;
+struct Label;
 
 struct Command;
 

Modified: scummvm/trunk/engines/parallaction/graphics.cpp
===================================================================
--- scummvm/trunk/engines/parallaction/graphics.cpp	2007-03-17 20:48:23 UTC (rev 26183)
+++ scummvm/trunk/engines/parallaction/graphics.cpp	2007-03-17 20:51:13 UTC (rev 26184)
@@ -413,7 +413,7 @@
 
 void jobDisplayLabel(void *parm, Job *j) {
 
-	ZoneLabel *label = (ZoneLabel*)parm;
+	Label *label = (Label*)parm;
 	debugC(1, kDebugJobs, "jobDisplayLabel (%p)", (const void*) label);
 
 	if (label->_cnv._width == 0)
@@ -424,7 +424,7 @@
 }
 
 void jobEraseLabel(void *parm, Job *j) {
-	ZoneLabel *label = (ZoneLabel*)parm;
+	Label *label = (Label*)parm;
 
 	debugC(1, kDebugJobs, "jobEraseLabel (%p)", (const void*) label);
 

Modified: scummvm/trunk/engines/parallaction/parallaction.h
===================================================================
--- scummvm/trunk/engines/parallaction/parallaction.h	2007-03-17 20:48:23 UTC (rev 26183)
+++ scummvm/trunk/engines/parallaction/parallaction.h	2007-03-17 20:51:13 UTC (rev 26184)
@@ -343,7 +343,7 @@
 
 		int16       _inventoryIndex;
 		Zone*       _zone;
-		ZoneLabel*  _label;
+		Label*  _label;
 	};
 
 	bool		_skipMenu;

Modified: scummvm/trunk/engines/parallaction/zone.cpp
===================================================================
--- scummvm/trunk/engines/parallaction/zone.h	2007-03-17 20:48:23 UTC (rev 26183)
+++ scummvm/trunk/engines/parallaction/zone.h	2007-03-17 20:51:13 UTC (rev 26184)
@@ -109,7 +109,7 @@
 	uint32	_obj3;
 };
 
-struct ZoneTypeData {
+struct TypeData {
 	GetData 	*get;
 	SpeakData	*speak;
 	ExamineData *examine;
@@ -118,7 +118,7 @@
 	MergeData	*merge;
 };
 
-struct ZoneLabel {
+struct Label {
 	char*			_text;
 	StaticCnv		_cnv;
 };
@@ -134,10 +134,10 @@
 
 	uint32			_type;
 	uint32			_flags;
-	ZoneLabel       _label;
+	Label       _label;
 	uint16			field_2C;		// unused
 	uint16			field_2E;		// unused
-	ZoneTypeData	u;
+	TypeData	u;
 	Command 		*_commands;
 	Point			_moveTo;
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/parallaction/zone.cpp	2007-03-17 20:48:23 UTC (rev 26183)
+++ scummvm/trunk/engines/parallaction/zone.cpp	2007-03-17 20:51:13 UTC (rev 26184)
@@ -128,7 +128,7 @@
 
 	for (; z; ) {
 
 		// WORKAROUND: this huge condition is needed because we made ZoneTypeData a collection of structs
 		// instead of an union. So, merge->_obj1 and get->_icon were just aliases in the original engine,
 		// but we need to check it separately here. The same workaround is applied in hitZone.
 		if (((z->_top == -1) ||
@@ -208,7 +208,7 @@
 void Parallaction::parseZoneTypeBlock(Script &script, Zone *z) {
 //	printf("parseZoneTypeBlock()");
 
-	ZoneTypeData *u = &z->u;
+	TypeData *u = &z->u;
 
 	switch (z->_type & 0xFFFF) {
 	case kZoneExamine:	// examine Zone alloc
@@ -589,7 +589,7 @@
 			// out of Zone, so look for special values
 			if ((z->_left == -2) || (z->_left == -3)) {
 
 				// WORKAROUND: this huge condition is needed because we made ZoneTypeData a collection of structs
 				// instead of an union. So, merge->_obj1 and get->_icon were just aliases in the original engine,
 				// but we need to check it separately here. The same workaround is applied in freeZones.
 				if ((((z->_type & 0xFFFF) == kZoneMerge) && (((_si == z->u.merge->_obj1) && (_di == z->u.merge->_obj2)) || ((_si == z->u.merge->_obj2) && (_di == z->u.merge->_obj1)))) ||
@@ -128,7 +128,7 @@
 	for (; z; ) {
 
-		// WORKAROUND: this huge condition is needed because we made ZoneTypeData a collection of structs
+		// WORKAROUND: this huge condition is needed because we made TypeData a collection of structs
 		// instead of an union. So, merge->_obj1 and get->_icon were just aliases in the original engine,
 		// but we need to check it separately here. The same workaround is applied in hitZone.
@@ -589,7 +589,7 @@
 			if ((z->_left == -2) || (z->_left == -3)) {
 
-				// WORKAROUND: this huge condition is needed because we made ZoneTypeData a collection of structs
+				// WORKAROUND: this huge condition is needed because we made TypeData a collection of structs
 				// instead of an union. So, merge->_obj1 and get->_icon were just aliases in the original engine,
 				// but we need to check it separately here. The same workaround is applied in freeZones.

Modified: scummvm/trunk/engines/parallaction/zone.h
===================================================================